@@ -20,10 +20,10 @@ class MxitGA(object):
 			return
 		try:
 			visitor = Visitor()
-			visitor.ip_address = request.headers['X-Forwarded-For']
+			visitor.ip_address = request.headers['X-Forwarded-For'].split(',')[-1].strip()
 			#TODO: Persist sessions.
 			session = Session()
 			page = Page(request.path)
 			self.tracker.track_pageview(page, session, visitor)
 		except Exception as e:
-			print('Problem tracking event: %s\nProblem:\n%s' % (str(request), e))
\ No newline at end of file
+			print('Problem tracking event: %s\nProblem:\n%s' % (str(request), e))
